testProportionality tests the hazard ratio proportionality assumption
of a Cyclops model fit object using a score test
testProportionality(object, parm = NULL, transform = "km")A Cyclops model fit object
A specification of which parameters require a proportionality test, either a vector of numbers or covariateId names
Same as transform in cox.zph